import { IMark } from './IMark';
import { IManuscriptComposable } from './IMarkedText';
export interface IController {
    link(composable: IManuscriptComposable): void;
    unlink(): void;
    deselect(immediate?: boolean): void;
    selectNew(begChar: number, endChar: number): void;
    selectMarks(marks: IMark[]): void;
    onMouseUpText(e: Event, charRange: [number, number]): void;
    onMouseUpMark(e: Event, charRange: [number, number], marks: IMark[]): void;
    onMouseUpSelection(e: Event, charRange: [number, number]): void;
    onMouseUpMetaString(e: Event, charRange: [number, number], metaStringText: string): void;
    onMouseUpOther(e: Event): void;
}
export declare abstract class AController implements IController {
    protected composable: IManuscriptComposable | null;
    link(composable: IManuscriptComposable): void;
    unlink(): void;
    abstract deselect(immediate?: boolean): void;
    abstract selectNew(begChar: number, endChar: number): void;
    abstract selectMarks(marks: IMark[]): void;
    abstract onMouseUpText(e: Event, charRange: [number, number]): void;
    abstract onMouseUpMark(e: Event, charRange: [number, number], marks: IMark[]): void;
    abstract onMouseUpSelection(e: Event, charRange: [number, number]): void;
    abstract onMouseUpMetaString(e: Event, charRange: [number, number], metaStringText: string): void;
    abstract onMouseUpOther(e: Event): void;
}
declare class NullController extends AController {
    deselect(): void;
    selectNew(): void;
    selectMarks(): void;
    onMouseUpText(): void;
    onMouseUpMark(): void;
    onMouseUpSelection(): void;
    onMouseUpMetaString(): void;
    onMouseUpOther(): void;
}
declare class TextSelectionController extends AController {
    private deselectCbk;
    private selectNewCbk;
    private selectMarksCbk;
    constructor(deselectCbk: TextSelectionController['deselectCbk'], selectNewCbk: TextSelectionController['selectNewCbk'], selectMarksCbk: TextSelectionController['selectMarksCbk']);
    deselect(immediate?: boolean): void;
    selectNew(begChar: number, endChar: number): void;
    selectMarks(marks: IMark[]): void;
    onMouseUpText(e: Event, charRange: [number, number]): void;
    onMouseUpMark(e: Event, charRange: [number, number], marks: IMark[]): void;
    onMouseUpSelection(e: Event, charRange: [number, number]): void;
    onMouseUpMetaString(e: Event, charRange: [number, number], metaStringText: string): void;
    onMouseUpOther(e: Event): void;
}
declare class WordSelectionController extends TextSelectionController {
    onMouseUpText(e: Event, charRange: [number, number]): void;
}
declare class TwoClickController extends TextSelectionController {
    private clickState;
    private anchorNode;
    private anchorOffset;
    private onFirstClick;
    private onSecondClick;
    private resetClick;
    onMouseUpText(e: Event, charRange: [number, number]): void;
    onMouseUpMark(e: Event, charRange: [number, number], marks: IMark[]): void;
    onMouseUpSelection(e: Event, charRange: [number, number]): void;
    onMouseUpMetaString(e: Event, charRange: [number, number], metaStringText: string): void;
    onMouseUpOther(e: Event): void;
}
export { NullController, TextSelectionController, WordSelectionController, TwoClickController };
