import { IMark } from '../IMark';
import { SpanData } from '../SpanData';
import { type MetaStringType } from './MetaString';
export interface IManuscript {
    readonly baseText: string;
    selection: [number, number] | null;
    batchSize: number;
    waitForReady(): void;
    setSelection(newSelection: [number, number] | null, immediate?: boolean): void;
    readonly spanBatches: SpanData[][];
    refresh(): void;
    resetSpans(): void;
    changeMarks(newMarks: IMark[], immediate?: boolean): void;
    metaStringEncloseSections(begSections: number[], endSections: number[]): void;
    metaStringDivideBatches(): void;
    removeMetaStrings(metaStringType?: MetaStringType): void;
}
export declare class Manuscript implements IManuscript {
    private text;
    private layers;
    private depotBatchSize;
    private selectionCharRange;
    private syncedSpanBatches;
    private press;
    private metaStringLookup;
    constructor(text: string, marks: IMark[], batchSize?: number, textSpanMaxLength?: number);
    waitForReady(): Promise<void>;
    get baseText(): string;
    get batchSize(): number;
    set batchSize(val: number);
    get selection(): [number, number] | null;
    set selection(newSelection: [number, number] | null);
    setSelection(newSelection: [number, number] | null, immediate?: boolean): void;
    get spanBatches(): SpanData[][];
    refresh(): void;
    resetSpans(): void;
    changeMarks(newMarks: IMark[], immediate?: boolean): void;
    metaStringEncloseSections(begSections: number[], endSections: number[]): void;
    metaStringDivideBatches(): void;
    removeMetaStrings(metaStringType?: MetaStringType): void;
    private setMetaStrings;
    private refreshMetaStrings;
}
